summaryrefslogtreecommitdiff
path: root/mpn/mips3/mul_1.s
diff options
context:
space:
mode:
Diffstat (limited to 'mpn/mips3/mul_1.s')
-rw-r--r--mpn/mips3/mul_1.s10
1 files changed, 5 insertions, 5 deletions
diff --git a/mpn/mips3/mul_1.s b/mpn/mips3/mul_1.s
index 281d0574a..9d71c469b 100644
--- a/mpn/mips3/mul_1.s
+++ b/mpn/mips3/mul_1.s
@@ -1,4 +1,4 @@
# MIPS3 __mpn_mul_1 -- Multiply a limb vector with a single limb and
# store the product in a second limb vector.
# Copyright (C) 1992, 1994, 1995 Free Software Foundation, Inc.
@@ -29,9 +29,9 @@
.text
.align 4
- .globl __mpn_mul_1
- .ent __mpn_mul_1
-__mpn_mul_1:
+ .globl __gmpn_mul_1
+ .ent __gmpn_mul_1
+__gmpn_mul_1:
.set noreorder
.set nomacro
@@ -82,4 +82,4 @@ $LC0: mflo $10
j $31
daddu $2,$9,$2 # add high product limb and carry from addition
- .end __mpn_mul_1
+ .end __gmpn_mul_1
@@ -1,4 +1,4 @@
- # MIPS3 __mpn_mul_1 -- Multiply a limb vector with a single limb and
+ # MIPS3 __gmpn_mul_1 -- Multiply a limb vector with a single limb and
# store the product in a second limb vector.
# Copyright (C) 1992, 1994, 1995 Free Software Foundation, Inc.